==> zio-aws-clouddirectory_3-5.17.130.5-sources.jar: zio/aws/clouddirectory/model/ListTypedLinkFacetNamesRequest.scala <==
package zio.aws.clouddirectory.model
import java.lang.Integer
import zio.aws.clouddirectory.model.primitives.{NumberResults, NextToken, Arn}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListTypedLinkFacetNamesRequest(
    schemaArn: Arn,
    nextToken: Option[NextToken] = None,
    maxResults: Option[NumberResults] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest = {
    import ListTypedLinkFacetNamesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest
      .builder()
      .schemaArn(Arn.unwrap(schemaArn): java.lang.String)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => NumberResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest.ReadOnly =
    zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest
      .wrap(buildAwsValue())
}
object ListTypedLinkFacetNamesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest =
      zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest(
        schemaArn,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def schemaArn: Arn
    def nextToken: Option[NextToken]
    def maxResults: Option[NumberResults]
    def getSchemaArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(schemaArn)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, NumberResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest
  ) extends zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest.ReadOnly {
    override val schemaArn: Arn =
      zio.aws.clouddirectory.model.primitives.Arn(impl.schemaArn())
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.clouddirectory.model.primitives.NextToken(value))
    override val maxResults: Option[NumberResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.clouddirectory.model.primitives.NumberResults(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest
  ): zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-clouddirectory_3-5.20.37.1-sources.jar: zio/aws/clouddirectory/model/ListTypedLinkFacetNamesRequest.scala <==
package zio.aws.clouddirectory.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.clouddirectory.model.primitives.{NumberResults, NextToken, Arn}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListTypedLinkFacetNamesRequest(
    schemaArn: Arn,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[NumberResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest = {
    import ListTypedLinkFacetNamesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest
      .builder()
      .schemaArn(Arn.unwrap(schemaArn): java.lang.String)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => NumberResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest.ReadOnly =
    zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest
      .wrap(buildAwsValue())
}
object ListTypedLinkFacetNamesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest =
      zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest(
        schemaArn,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def schemaArn: Arn
    def nextToken: Optional[NextToken]
    def maxResults: Optional[NumberResults]
    def getSchemaArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(schemaArn)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, NumberResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest
  ) extends zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest.ReadOnly {
    override val schemaArn: Arn =
      zio.aws.clouddirectory.model.primitives.Arn(impl.schemaArn())
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.clouddirectory.model.primitives.NextToken(value))
    override val maxResults: Optional[NumberResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.clouddirectory.model.primitives.NumberResults(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.ListTypedLinkFacetNamesRequest
  ): zio.aws.clouddirectory.model.ListTypedLinkFacetNamesRequest.ReadOnly =
    new Wrapper(impl)
}
